include(header.m4)
define(CURRENT_PROGRAM,para_audiod)
define(DEFAULT_CONFIG_FILE,~/.paraslash/audiod.conf)

<qu>
#########################
section "General options"
#########################
</qu>

include(loglevel.m4)
include(color.m4)
include(config_file.m4)
include(logfile.m4)
include(daemon.m4)
include(user.m4)
include(group.m4)

<qu>
########################
section "Audiod options"
########################

option "force" F
#~~~~~~~~~~~~~~~
"force startup"
flag off
details="
	If this flag is not given, para_audiod refuses to start if the
	well-known socket file (see the --socket option) already exists
	because this usually means that para_audiod is already running
	and listening on that socket. After a crash or if para_audiod
	received a SIGKILL signal, a stale socket file might remain and
	you have to use --force once to force startup of para_audiod.
"

option "mode" m
#~~~~~~~~~~~~~~
"startup mode"
string typestr="mode"
default="on"
optional
details="
	Para_audiod supports three modes of operation: On, off and
	standby (sb).  This option selects the mode that should be
	used on startup. If para_audiod operates in \"on\" mode, it
	will connect to para_server in order to receive its status
	information. If para_server announces the availability of an
	audio stream, para_audiod will automatically download, decode
	and play the audio stream according to the given stream I/O
	options, see below.

	In \"standby\" mode, para_audiod will only receive the
	status information from para_server but will not download
	the audio stream.

	In \"off\" mode, para_audiod does not connect para_server at
	all, but still listens on the local socket for connections.
"

option "socket" s
#~~~~~~~~~~~~~~~~
"well-known socket"
string typestr="filename"
optional
details="
	Para_audiod uses a \"well-known\" socket to listen
	on for connections from para_audioc. This socket is a
	special file in the file system; its location defaults to
	/var/paraslash/audiod_sock.<host_name>.

	para_audioc, the client program used to connect to para_audiod,
	opens this socket in order to talk to para_audiod.  If the
	default value for para_audiod is changed, para_audioc must be
	instructed to use also \"filename\" for connecting para_audiod.
"

option "user_allow" -
#~~~~~~~~~~~~~~~~~~~~
"allow this uid"
int typestr="uid"
default="-1"
optional
multiple
details="
	Allow the user identified by \"uid\" to connect to para_audiod.
	May be specified multiple times. If not specified at all,
	all users are allowed to connect.

	This feature requires unix socket credentials and is currently
	only supported on Linux systems. On other operating systems,
	the option is silently ignored and all local users are allowed
	to connect to para_audiod.
"

option "clock_diff_count" -
#~~~~~~~~~~~~~~~~~~~~~~~~~~
"sync clock on startup"
int typestr="count"
default="0"
optional
details="
	Check the clock difference between the host running para_server
	and the local host running para_audiod that many times before
	starting any stream I/0. Set this to non-zero for non-local
	setups if the clocks of these two hosts are not syncronized
	by ntp or similar.
"

#############################
section "Stream I/O options"
#############################

option "receiver" r
#~~~~~~~~~~~~~~~~~~
"select receiver"
string typestr="receiver_spec"
default="http"
optional
multiple
details="
	This option may be given multiple times, once for each
	supported audio format. The \"receiver_spec\" consists of
	an audio format and the receiver name, separated by a colon,
	and any options for that receiver, seperated by whitespace.
	If any receiver options are present, the whole receiver
	argument must be quoted.

	Example:

		-r 'mp3:http -i my.host.org -p 8009'
"

option "no_default_filters" D
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~
"Configure filters manually"
flag off
details="
	If (and only if) this option is set, the --filter options
	(see below) take effect. Otherwise, the compiled-in default
	filters mp3dec, oggdec and aacdec are activated for mp3, ogg,
	aac streams respectively.

	You have to configure filters manually if you want to use
	the amp filter or the compress filter which are not activated
	by default.

	Playing udp streams also requires manual filter configuration
	because the output of the udp receiver must be fed into the
	fecdec filter first to produce a stream which can be decoded
	by the appropriate decoder (mp3dec, oggdec, aacdec). In other
	words, the fecdec filter must be specified as the first filter
	of the filter chain for any udp stream.
"

option "filter" f
#~~~~~~~~~~~~~~~~
"Use non-default filters"
string typestr="filter_spec"
optional
multiple
dependon="no_default_filters"
details="
	This option may be given multiple times. The \"filter_spec\"
	consists of an audio format, the name of the filter, and any
	options for that filter. Note that order matters.

	Examples:

		--filter 'mp3:mp3dec'

		--filter 'mp3:compress --inertia 5 --damp 2'

"

option "writer" w
#~~~~~~~~~~~~~~~~
"Specify stream writer."
string typestr="writer_spec"
optional
multiple
details="
	May be given multiple times, even multiple times for the same
	audio format.  Default value is \"alsa\" for all supported
	audio formats. Example:

		--writer 'aac:osx'

"

option "stream_delay" -
#~~~~~~~~~~~~~~~~~~~~~~
"time for client sync"
int typestr="milliseconds"
default="200"
optional
details="
	Add the given amount of milliseconds to the stream start time
	announced by para_server and do not send data to the writer
	before that time (modulo clock difference).

	This is useful mainly for syncronizing the audio output of
	different clients.
"
</qu>
